==> mediawiki-1.33.1-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/languages/messages/MessagesAvk.php <==
<?php
/** Kotava (Kotava)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

$namespaceNames = [
	NS_MEDIA            => 'Mamind',
	NS_SPECIAL          => 'Aptaca',
	NS_TALK             => 'Prilara',
	NS_USER             => 'Favesik',
	NS_USER_TALK        => 'Favesikprilara',
	NS_PROJECT_TALK     => '$1_prilara',
	NS_FILE             => 'Ewava',
	NS_FILE_TALK        => 'Ewavaprilara',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWiki_prilara',
	NS_TEMPLATE         => 'Teza',
	NS_TEMPLATE_TALK    => 'Tezaprilara',
	NS_HELP             => 'Pomara',
	NS_HELP_TALK        => 'Pomaraprilara',
	NS_CATEGORY         => 'Loma',
	NS_CATEGORY_TALK    => 'Lomaprilara',
];

$specialPageAliases = [
	'Allmessages'               => [ 'Stakseem' ],
	'Allpages'                  => [ 'Bueem' ],
	'Ancientpages'              => [ 'SavsafBueem' ],
	'Booksources'               => [ 'NevaKliteem' ],
	'BrokenRedirects'           => [ 'EmpayanGraskakseem' ],
	'Categories'                => [ 'Lomeem' ],
	'Confirmemail'              => [ 'EmailManeGruyera' ],
	'Contributions'             => [ 'Webekseem' ],
	'Deadendpages'              => [ 'AxodafBueem' ],
	'DoubleRedirects'           => [ 'JontolafGraskakseem' ],
	'Emailuser'                 => [ 'FavesikEmailMane' ],
	'Export'                    => [ 'Divburera' ],
	'Fewestrevisions'           => [ 'Lebetayan' ],
	'Import'                    => [ 'Koburera' ],
	'Listadmins'                => [ 'Ristusikeem' ],
	'Listbots'                  => [ 'Stiernikeem' ],
	'Listfiles'                 => [ 'Ewaveem' ],
	'Listredirects'             => [ 'Graskakseem' ],
	'Listusers'                 => [ 'Favesikeem' ],
	'Lonelypages'               => [ 'GluyasikiiskafBueem' ],
	'Longpages'                 => [ 'AbrotcafBueem' ],
	'MIMEsearch'                => [ 'MIMEAneyara' ],
	'Mostcategories'            => [ 'Lolomakiraf' ],
	'Mostimages'                => [ 'Lodewavakiraf' ],
	'Mostlinked'                => [ 'Logluyasikikiraf' ],
	'Mostlinkedcategories'      => [ 'LogluyasikirafLomeem' ],
	'Mostlinkedtemplates'       => [ 'LogluyasikikirafTezeem' ],
	'Mostrevisions'             => [ 'Lobetayan' ],
	'Movepage'                  => [ 'BuArrundara' ],
	'Mycontributions'           => [ 'JinafWebekseem' ],
	'Mypage'                    => [ 'JinafuBu' ],
	'Mytalk'                    => [ 'JinafaPrilara' ],
	'Newimages'                 => [ 'WarzafEwaveem' ],
	'Newpages'                  => [ 'WarzafBueem' ],
	'Preferences'               => [ 'Lodamaceem' ],
	'Protectedpages'            => [ 'NendanBueem' ],
	'Protectedtitles'           => [ 'NendanVergumvelteem' ],
	'Randompage'                => [ 'Xuyavabu' ],
	'Randomredirect'            => [ 'XuyavafaGraskara' ],
	'Recentchanges'             => [ 'NoeltafBetakseem' ],
	'Revisiondelete'            => [ 'BetaraSulara' ],
	'Search'                    => [ 'Aneyara' ],
	'Shortpages'                => [ 'TrelafBueem' ],
	'Specialpages'              => [ 'AptafBueem' ],
	'Statistics'                => [ 'Enkopaceem' ],
	'Uncategorizedcategories'   => [ 'LomiskafLomeem' ],
	'Uncategorizedimages'       => [ 'LomiskafEwaveem' ],
	'Uncategorizedpages'        => [ 'LomiskafBueem' ],
	'Uncategorizedtemplates'    => [ 'LomiskafTezeem' ],
	'Undelete'                  => [ 'Dimsulara' ],
	'Unusedcategories'          => [ 'MefavenLomeem' ],
	'Unusedimages'              => [ 'MefavenEwaveem' ],
	'Unusedtemplates'           => [ 'MefavenTezeem' ],
	'Unwatchedpages'            => [ 'MerupenBueem' ],
	'Upload'                    => [ 'Kalvajara' ],
	'Userrights'                => [ 'FavesikRokeem' ],
	'Version'                   => [ 'Siatos' ],
	'Wantedcategories'          => [ 'ErunLomeem' ],
	'Wantedpages'               => [ 'ErunBueem', 'EmpayanGluyasikieem' ],
	'Watchlist'                 => [ 'Suzdasiki' ],
];

==> mediawiki-1.36.1-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/languages/messages/MessagesAvk.php <==
<?php
/** Kotava (Kotava)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

$fallback = 'fr, es, ru';

$namespaceNames = [
	NS_MEDIA            => 'Kanaca',
	NS_SPECIAL          => 'Aptaca',
	NS_TALK             => 'Prilara',
	NS_USER             => 'Favesik',
	NS_USER_TALK        => 'Favesikprilara',
	NS_PROJECT_TALK     => '$1_prilara',
	NS_FILE             => 'Iyeltak',
	NS_FILE_TALK        => 'Iyeltakprilara',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWiki_prilara',
	NS_TEMPLATE         => 'Teza',
	NS_TEMPLATE_TALK    => 'Tezaprilara',
	NS_HELP             => 'Pomara',
	NS_HELP_TALK        => 'Pomaraprilara',
	NS_CATEGORY         => 'Loma',
	NS_CATEGORY_TALK    => 'Lomaprilara',
];

$namespaceAliases = [
	'Mamind' => NS_MEDIA,
	'Ewava' => NS_FILE,
	'Ewavaprilara' => NS_FILE_TALK,
];

/** @phpcs-require-sorted-array */
$specialPageAliases = [
	'Allmessages'               => [ 'Stakseem' ],
	'Allpages'                  => [ 'Bueem' ],
	'Ancientpages'              => [ 'SavsafBueem' ],
	'Booksources'               => [ 'NevaKliteem' ],
	'BrokenRedirects'           => [ 'EmpayanGraskakseem' ],
	'Categories'                => [ 'Lomeem' ],
	'Confirmemail'              => [ 'EmailManeGruyera' ],
	'Contributions'             => [ 'Webekseem' ],
	'Deadendpages'              => [ 'AxodafBueem' ],
	'DoubleRedirects'           => [ 'JontolafGraskakseem' ],
	'Emailuser'                 => [ 'FavesikEmailMane' ],
	'Export'                    => [ 'Divburera' ],
	'Fewestrevisions'           => [ 'Lebetayan' ],
	'Import'                    => [ 'Koburera' ],
	'Listadmins'                => [ 'Ristusikeem' ],
	'Listbots'                  => [ 'Stiernikeem' ],
	'Listfiles'                 => [ 'Ewaveem' ],
	'Listredirects'             => [ 'Graskakseem' ],
	'Listusers'                 => [ 'Favesikeem' ],
	'Lonelypages'               => [ 'GluyasikiiskafBueem' ],
	'Longpages'                 => [ 'AbrotcafBueem' ],
	'MIMEsearch'                => [ 'MIMEAneyara' ],
	'Mostcategories'            => [ 'Lolomakiraf' ],
	'Mostimages'                => [ 'Lodewavakiraf' ],
	'Mostlinked'                => [ 'Logluyasikikiraf' ],
	'Mostlinkedcategories'      => [ 'LogluyasikirafLomeem' ],
	'Mostlinkedtemplates'       => [ 'LogluyasikikirafTezeem' ],
	'Mostrevisions'             => [ 'Lobetayan' ],
	'Movepage'                  => [ 'BuArrundara' ],
	'Mycontributions'           => [ 'JinafWebekseem' ],
	'Mypage'                    => [ 'JinafuBu' ],
	'Mytalk'                    => [ 'JinafaPrilara' ],
	'Newimages'                 => [ 'WarzafEwaveem' ],
	'Newpages'                  => [ 'WarzafBueem' ],
	'Preferences'               => [ 'Lodamaceem' ],
	'Protectedpages'            => [ 'NendanBueem' ],
	'Protectedtitles'           => [ 'NendanVergumvelteem' ],
	'Randompage'                => [ 'Xuyavabu' ],
	'Randomredirect'            => [ 'XuyavafaGraskara' ],
	'Recentchanges'             => [ 'NoeltafBetakseem' ],
	'Revisiondelete'            => [ 'BetaraSulara' ],
	'Search'                    => [ 'Aneyara' ],
	'Shortpages'                => [ 'TrelafBueem' ],
	'Specialpages'              => [ 'AptafBueem' ],
	'Statistics'                => [ 'Enkopaceem' ],
	'Uncategorizedcategories'   => [ 'LomiskafLomeem' ],
	'Uncategorizedimages'       => [ 'LomiskafEwaveem' ],
	'Uncategorizedpages'        => [ 'LomiskafBueem' ],
	'Uncategorizedtemplates'    => [ 'LomiskafTezeem' ],
	'Undelete'                  => [ 'Dimsulara' ],
	'Unusedcategories'          => [ 'MefavenLomeem' ],
	'Unusedimages'              => [ 'MefavenEwaveem' ],
	'Unusedtemplates'           => [ 'MefavenTezeem' ],
	'Unwatchedpages'            => [ 'MerupenBueem' ],
	'Upload'                    => [ 'Kalvajara' ],
	'Userrights'                => [ 'FavesikRokeem' ],
	'Version'                   => [ 'Siatos' ],
	'Wantedcategories'          => [ 'ErunLomeem' ],
	'Wantedpages'               => [ 'ErunBueem', 'EmpayanGluyasikieem' ],
	'Watchlist'                 => [ 'Suzdasiki' ],
];
